==> credoai-lens-1.0.1.tar.gz: credoai-lens-1.0.1/credoai/artifacts/model/regression_model.py <==
"""Model artifact wrapping any regression model"""
from .base_model import Model


class RegressionModel(Model):
    """Class wrapper around classification model to be assessed

    RegressionModel serves as an adapter between arbitrary regression models and the
    evaluations in Lens. Evaluations depend on
    RegressionModel instantiating `predict`

    Parameters
    ----------
    name : str
        Label of the model
    model_like : model_like
        A binary or multi-class classification model or pipeline. It must have a
            `predict` function that returns array containing the class labels for each sample.
            It can also optionally have a `predict_proba` function that returns array containing
            the class labels probabilities for each sample.
    """

    def __init__(self, name: str, model_like=None):
        super().__init__(
            "Regression",
            ["predict"],
            ["predict"],
            name,
            model_like,
        )


class DummyRegression:
    """Class wrapper around regression model predictions

    This class can be used when a regression model is not available but its outputs are.
    The output include the array containing the predicted class labels and/or the array
    containing the class labels probabilities.
    Wrap the outputs with this class into a dummy classifier and pass it as
    the model to `RegressionModel`.

    Parameters
    ----------
    predict_output : array
        Array containing the output of a model's "predict" method
    """

    def __init__(self, predict_output=None):
        self.predict_output = predict_output

    def predict(self, X=None):
        return self.predict_output

==> credoai-lens-1.1.3.tar.gz: credoai-lens-1.1.3/credoai/artifacts/model/regression_model.py <==
"""Model artifact wrapping any regression model"""
from .base_model import Model


class RegressionModel(Model):
    """Class wrapper around classification model to be assessed

    RegressionModel serves as an adapter between arbitrary regression models and the
    evaluations in Lens. Evaluations depend on
    RegressionModel instantiating `predict`

    Parameters
    ----------
    name : str
        Label of the model
    model_like : model_like
        A continuous output regression model or pipeline. It must have a
            `predict` function that returns array containing the predicted outcomes for each sample.
    """

    def __init__(self, name: str, model_like=None, tags=None):
        super().__init__("REGRESSION", ["predict"], ["predict"], name, model_like, tags)


class DummyRegression:
    """Class wrapper around regression model predictions

    This class can be used when a regression model is not available but its outputs are.
    The output include the array containing the predicted class labels and/or the array
    containing the class labels probabilities.
    Wrap the outputs with this class into a dummy classifier and pass it as
    the model to `RegressionModel`.

    Parameters
    ----------
    predict_output : array
        Array containing the output of a model's "predict" method
    """

    def __init__(self, name: str, predict_output=None, tags=None):
        self.predict_output = predict_output
        self.name = name
        self.tags = tags

    def predict(self, X=None):
        return self.predict_output
